@@ -1,15 +1,14 @@
 from logging.config import fileConfig
+
+import freenit.app
+from alembic import context
+
 from .models import *
 
-from alembic import context
-from freenit.config import getConfig
-import freenit.app
-
-config = getConfig()
 fileConfig(context.config.config_file_name)
 
 
-def run_migrations_offline():
+def run_migrations_offline(config):
     context.configure(
         url=config.dburl,
         target_metadata=config.metadata,
@@ -21,7 +20,7 @@ def run_migrations_offline():
         context.run_migrations()
 
 
-def run_migrations_online():
+def run_migrations_online(config):
     connectable = config.engine
     with connectable.connect() as connection:
         context.configure(
